==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acu&egrave;lh dau sit',
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Los articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'I a ges d\'article a aquela adre&ccedil;a ',
'aucun_auteur' => 'I a ges d\'autor a aquela adre&ccedil;a ',
'aucun_site' => 'I a ges de sit a aquela adre&ccedil;a ',
'aucune_breve' => 'I a ges de br&egrave;va a aquela adre&ccedil;a ',
'aucune_rubrique' => 'I a ges de rubrica a aquela adre&ccedil;a ',
'autres_breves' => 'Autras br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autres grops de mots claus',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'Bonjorn',
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aquel sit',

// D
'date' => 'Data',
'dernier_ajout' => 'Darr&egrave;ir apondon',
'dernieres_breves' => 'Darr&egrave;iras br&egrave;vas',
'derniers_articles' => 'Darr&egrave;irs articles',
'derniers_commentaires' => 'Darr&egrave;irs comentaris',
'derniers_messages_forum' => 'Darr&egrave;irs messatges publicats dins los forums',

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En responsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// M
'meme_auteur' => 'Dau mesme autor',
'meme_rubrique' => 'Dins la mesma rubrica',
'memes_auteurs' => 'Daus mesmes autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Los messatges de forums mai recents',
'mots_clefs' => 'Mots claus',
'mots_clefs_meme_groupe' => 'Mots claus dins lo mesme grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Las novetats',
'nouveautes_web' => 'Novetats sobre lo web',
'nouveaux_articles' => 'Articles nu&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas nu&ograve;vas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Pod&egrave;tz participar a la vida d\'aquel sit e prepausar los articles v&ograve;stres en vos inscriure &ccedil;ai sos. Recebretz tot sit&ograve;st un e-mail que vos indicar&aacute; v&ograve;stres c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepausar un sit d\'apondre a aquesta rubrica:',

// R
'repondre_article' => 'Respondre a aquel article',
'repondre_breve' => 'Respondre a aquela br&egrave;va',
'repondre_message' => 'Respondre a aquel messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rcha',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament daus forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat amb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'suite' => 'seguda',
'sur_web' => 'Sobre lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vaic&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa los articles e br&egrave;vas publicats dempu&egrave;i',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vejatz en linha',
'voir_squelette' => 'telecharjar l\'esqueleta d\'aquela pagina'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acu&egrave;lh dau sit',
'article' => 'Article', # NEW
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Los articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'I a ges d\'article a aquela adre&ccedil;a ',
'aucun_auteur' => 'I a ges d\'autor a aquela adre&ccedil;a ',
'aucun_site' => 'I a ges de sit a aquela adre&ccedil;a ',
'aucune_breve' => 'I a ges de br&egrave;va a aquela adre&ccedil;a ',
'aucune_rubrique' => 'I a ges de rubrica a aquela adre&ccedil;a ',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Autras br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autres grops de mots claus',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'Bonjorn',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aquel sit',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Data',
'dernier_ajout' => 'Darr&egrave;ir apondon',
'dernieres_breves' => 'Darr&egrave;iras br&egrave;vas',
'derniers_articles' => 'Darr&egrave;irs articles',
'derniers_commentaires' => 'Darr&egrave;irs comentaris',
'derniers_messages_forum' => 'Darr&egrave;irs messatges publicats dins los forums',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En responsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Dau mesme autor',
'meme_rubrique' => 'Dins la mesma rubrica',
'memes_auteurs' => 'Daus mesmes autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Los messatges de forums mai recents',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Mots claus',
'mots_clefs_meme_groupe' => 'Mots claus dins lo mesme grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Las novetats',
'nouveautes_web' => 'Novetats sobre lo web',
'nouveaux_articles' => 'Articles nu&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas nu&ograve;vas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Pod&egrave;tz participar a la vida d\'aquel sit e prepausar los articles v&ograve;stres en vos inscriure &ccedil;ai sos. Recebretz tot sit&ograve;st un e-mail que vos indicar&aacute; v&ograve;stres c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepausar un sit d\'apondre a aquesta rubrica:',

// R
'repondre_article' => 'Respondre a aquel article',
'repondre_breve' => 'Respondre a aquela br&egrave;va',
'repondre_message' => 'Respondre a aquel messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rcha',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament daus forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat amb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'spam' => 'Spam', # NEW
'suite' => 'seguda',
'sur_web' => 'Sobre lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vaic&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa los articles e br&egrave;vas publicats dempu&egrave;i',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vejatz en linha',
'voir_squelette' => 'telecharjar l\'esqueleta d\'aquela pagina'
);

?>
